textures = {
	["arrow-white-01-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7490234375,
		y0 = 0.12255859375,
		x1 = 0.0810546875,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 83,
		trimmedheight = 50,
		untrimmedwidth = 83,
		untrimmedheight = 50,
	},
	["arrow-yellow-01-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.849609375,
		y0 = 0.1298828125,
		x1 = 0.0810546875,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 83,
		trimmedheight = 50,
		untrimmedwidth = 83,
		untrimmedheight = 50,
	},
	["barrel-blue-down-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6923828125,
		y0 = 0.3759765625,
		x1 = 0.0341796875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 24,
		untrimmedwidth = 35,
		untrimmedheight = 24,
	},
	["barrel-blue-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.07861328125,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["barrel-red-down-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6201171875,
		y0 = 0.373046875,
		x1 = 0.0341796875,
		y1 = 0.01171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 24,
		untrimmedwidth = 35,
		untrimmedheight = 24,
	},
	["barrel-red-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.09326171875,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["barrier-red-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.60546875,
		y0 = 0.1005859375,
		x1 = 0.1025390625,
		y1 = 0.01513671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 105,
		trimmedheight = 31,
		untrimmedwidth = 105,
		untrimmedheight = 31,
	},
	["barrier-red-race-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.60546875,
		y0 = 0.11669921875,
		x1 = 0.1025390625,
		y1 = 0.01513671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 105,
		trimmedheight = 31,
		untrimmedwidth = 105,
		untrimmedheight = 31,
	},
	["barrier-white-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.60546875,
		y0 = 0.1328125,
		x1 = 0.1025390625,
		y1 = 0.01513671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 105,
		trimmedheight = 31,
		untrimmedwidth = 105,
		untrimmedheight = 31,
	},
	["barrier-white-race-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7490234375,
		y0 = 0.1064453125,
		x1 = 0.1025390625,
		y1 = 0.01513671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 105,
		trimmedheight = 31,
		untrimmedwidth = 105,
		untrimmedheight = 31,
	},
	["car-black-01-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7080078125,
		y0 = 0.1533203125,
		x1 = 0.03515625,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 66,
		untrimmedwidth = 36,
		untrimmedheight = 66,
	},
	["car-black-02-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5634765625,
		y0 = 0.1533203125,
		x1 = 0.03515625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 58,
		untrimmedwidth = 36,
		untrimmedheight = 58,
	},
	["car-black-03-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8037109375,
		y0 = 0.27978515625,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-black-04-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.556640625,
		y0 = 0.2119140625,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-black-05-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.79296875,
		y0 = 0.34619140625,
		x1 = 0.0341796875,
		y1 = 0.02978515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 61,
		untrimmedwidth = 35,
		untrimmedheight = 61,
	},
	["car-blue-01-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.669921875,
		y0 = 0.16650390625,
		x1 = 0.03515625,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 66,
		untrimmedwidth = 36,
		untrimmedheight = 66,
	},
	["car-blue-02-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5634765625,
		y0 = 0.1826171875,
		x1 = 0.03515625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 58,
		untrimmedwidth = 36,
		untrimmedheight = 58,
	},
	["car-blue-03-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.556640625,
		y0 = 0.2451171875,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-blue-04-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6572265625,
		y0 = 0.24658203125,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-blue-05-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9580078125,
		y0 = 0.3701171875,
		x1 = 0.0341796875,
		y1 = 0.02978515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 61,
		untrimmedwidth = 35,
		untrimmedheight = 61,
	},
	["car-green-01-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.70703125,
		y0 = 0.1865234375,
		x1 = 0.03515625,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 66,
		untrimmedwidth = 36,
		untrimmedheight = 66,
	},
	["car-green-02-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6650390625,
		y0 = 0.19970703125,
		x1 = 0.03515625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 58,
		untrimmedwidth = 36,
		untrimmedheight = 58,
	},
	["car-green-03-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6572265625,
		y0 = 0.27978515625,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-green-04-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.693359375,
		y0 = 0.3095703125,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-green-05-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5556640625,
		y0 = 0.3115234375,
		x1 = 0.0341796875,
		y1 = 0.02978515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 61,
		untrimmedwidth = 35,
		untrimmedheight = 61,
	},
	["car-red-01-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8095703125,
		y0 = 0.18408203125,
		x1 = 0.03515625,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 66,
		untrimmedwidth = 36,
		untrimmedheight = 66,
	},
	["car-red-02-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7021484375,
		y0 = 0.2197265625,
		x1 = 0.03515625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 58,
		untrimmedwidth = 36,
		untrimmedheight = 58,
	},
	["car-red-03-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7939453125,
		y0 = 0.31298828125,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-red-04-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5556640625,
		y0 = 0.2783203125,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-red-05-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6201171875,
		y0 = 0.34228515625,
		x1 = 0.0341796875,
		y1 = 0.02978515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 61,
		untrimmedwidth = 35,
		untrimmedheight = 61,
	},
	["car-yellow-01-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.80859375,
		y0 = 0.21728515625,
		x1 = 0.03515625,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 66,
		untrimmedwidth = 36,
		untrimmedheight = 66,
	},
	["car-yellow-02-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8037109375,
		y0 = 0.25048828125,
		x1 = 0.03515625,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 36,
		trimmedheight = 58,
		untrimmedwidth = 36,
		untrimmedheight = 58,
	},
	["car-yellow-03-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.65625,
		y0 = 0.31298828125,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-yellow-04-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6923828125,
		y0 = 0.3427734375,
		x1 = 0.0341796875,
		y1 = 0.0322265625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 66,
		untrimmedwidth = 35,
		untrimmedheight = 66,
	},
	["car-yellow-05-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.65625,
		y0 = 0.34619140625,
		x1 = 0.0341796875,
		y1 = 0.02978515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 35,
		trimmedheight = 61,
		untrimmedwidth = 35,
		untrimmedheight = 61,
	},
	["cone-down-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9755859375,
		y0 = 0.201171875,
		x1 = 0.0224609375,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 23,
		trimmedheight = 22,
		untrimmedwidth = 23,
		untrimmedheight = 22,
	},
	["cone-straight-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9755859375,
		y0 = 0.212890625,
		x1 = 0.0224609375,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 23,
		trimmedheight = 22,
		untrimmedwidth = 23,
		untrimmedheight = 22,
	},
	["land-dirt-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.93359375,
		y0 = 0.1044921875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9326171875,
		y0 = 0.13671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.849609375,
		y0 = 0.1552734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9296875,
		y0 = 0.1689453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.60546875,
		y0 = 0.14892578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7451171875,
		y0 = 0.18359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.744140625,
		y0 = 0.2158203125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8466796875,
		y0 = 0.1875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9111328125,
		y0 = 0.201171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.845703125,
		y0 = 0.2197265625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.91015625,
		y0 = 0.2333984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.251953125,
		y0 = 0.1240234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.31640625,
		y0 = 0.1240234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-dirt-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.380859375,
		y0 = 0.1240234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4990234375,
		y0 = 0.1533203125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6005859375,
		y0 = 0.18115234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7392578125,
		y0 = 0.248046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8408203125,
		y0 = 0.251953125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9052734375,
		y0 = 0.265625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.2841796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.2978515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.24609375,
		y0 = 0.15625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.310546875,
		y0 = 0.15625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.375,
		y0 = 0.15625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4921875,
		y0 = 0.185546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5927734375,
		y0 = 0.21337890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.24609375,
		y0 = 0.1884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-grass-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.310546875,
		y0 = 0.1884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.375,
		y0 = 0.1884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4921875,
		y0 = 0.2177734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5927734375,
		y0 = 0.24560546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5927734375,
		y0 = 0.27783203125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7392578125,
		y0 = 0.2802734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7294921875,
		y0 = 0.3125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.830078125,
		y0 = 0.31640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.89453125,
		y0 = 0.330078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.18994140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.18994140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.18994140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.22216796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.22216796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["land-sand-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.22216796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["light-white"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.2021484375,
		x1 = 0.0478515625,
		y1 = 0.0576171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 118,
		untrimmedwidth = 49,
		untrimmedheight = 118,
	},
	["light-yellow"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.2607421875,
		x1 = 0.0478515625,
		y1 = 0.0576171875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 118,
		untrimmedwidth = 49,
		untrimmedheight = 118,
	},
	["lights"] = {
		image = "miniracer-0-small",
		x0 = 0.853515625,
		y0 = 0.11328125,
		x1 = 0.078125,
		y1 = 0.015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 80,
		trimmedheight = 32,
		untrimmedwidth = 80,
		untrimmedheight = 32,
	},
	["motorcycle-black"] = {
		image = "miniracer-0-small",
		x0 = 0.974609375,
		y0 = 0.24609375,
		x1 = 0.021484375,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 50,
		untrimmedwidth = 22,
		untrimmedheight = 50,
	},
	["motorcycle-blue"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.1513671875,
		x1 = 0.021484375,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 50,
		untrimmedwidth = 22,
		untrimmedheight = 50,
	},
	["motorcycle-green"] = {
		image = "miniracer-0-small",
		x0 = 0.9697265625,
		y0 = 0.271484375,
		x1 = 0.021484375,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 50,
		untrimmedwidth = 22,
		untrimmedheight = 50,
	},
	["motorcycle-red"] = {
		image = "miniracer-0-small",
		x0 = 0.9697265625,
		y0 = 0.296875,
		x1 = 0.021484375,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 50,
		untrimmedwidth = 22,
		untrimmedheight = 50,
	},
	["motorcycle-yellow"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.1767578125,
		x1 = 0.021484375,
		y1 = 0.0244140625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 50,
		untrimmedwidth = 22,
		untrimmedheight = 50,
	},
	["oil-01-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9404296875,
		y0 = 0.0009765625,
		x1 = 0.0537109375,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 55,
		trimmedheight = 48,
		untrimmedwidth = 55,
		untrimmedheight = 48,
	},
	["racer-black"] = {
		image = "miniracer-0-small",
		x0 = 0.4619140625,
		y0 = 0.380859375,
		x1 = 0.0205078125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 21,
		trimmedheight = 26,
		untrimmedwidth = 21,
		untrimmedheight = 26,
	},
	["racer-blue"] = {
		image = "miniracer-0-small",
		x0 = 0.779296875,
		y0 = 0.4736328125,
		x1 = 0.0205078125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 21,
		trimmedheight = 26,
		untrimmedwidth = 21,
		untrimmedheight = 26,
	},
	["racer-green"] = {
		image = "miniracer-0-small",
		x0 = 0.779296875,
		y0 = 0.4873046875,
		x1 = 0.0205078125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 21,
		trimmedheight = 26,
		untrimmedwidth = 21,
		untrimmedheight = 26,
	},
	["racer-red"] = {
		image = "miniracer-0-small",
		x0 = 0.779296875,
		y0 = 0.5009765625,
		x1 = 0.0205078125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 21,
		trimmedheight = 26,
		untrimmedwidth = 21,
		untrimmedheight = 26,
	},
	["racer-yellow"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.400390625,
		x1 = 0.0205078125,
		y1 = 0.0126953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 21,
		trimmedheight = 26,
		untrimmedwidth = 21,
		untrimmedheight = 26,
	},
	["road-asphalt-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.25439453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.25439453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.25439453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2451171875,
		y0 = 0.220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3095703125,
		y0 = 0.220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3740234375,
		y0 = 0.220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4912109375,
		y0 = 0.25,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9404296875,
		y0 = 0.025390625,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 11,
		trimmedoffsety = 12,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.591796875,
		y0 = 0.31005859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.728515625,
		y0 = 0.3447265625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.439453125,
		y0 = 0.1767578125,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 11,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.65625,
		y0 = 0.376953125,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8291015625,
		y0 = 0.3486328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8935546875,
		y0 = 0.3623046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-15-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.126953125,
		y0 = 0.77001953125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-16-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2451171875,
		y0 = 0.2529296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-17-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3095703125,
		y0 = 0.2529296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-18-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.126953125,
		y0 = 0.787109375,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-19-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3740234375,
		y0 = 0.2529296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-20-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4912109375,
		y0 = 0.2822265625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-21-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.28662109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-22-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.28662109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-23-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.28662109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-24-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.31884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-25-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.31884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-26-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.31884765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-27-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2451171875,
		y0 = 0.28515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-28-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3095703125,
		y0 = 0.28515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-29-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3740234375,
		y0 = 0.28515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-30-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4912109375,
		y0 = 0.314453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-31-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5556640625,
		y0 = 0.34228515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-32-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.79296875,
		y0 = 0.376953125,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-33-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.728515625,
		y0 = 0.376953125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-34-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8271484375,
		y0 = 0.380859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-35-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8916015625,
		y0 = 0.39453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-36-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.724609375,
		y0 = 0.4091796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-37-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8232421875,
		y0 = 0.4130859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-38-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8876953125,
		y0 = 0.4267578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-39-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2451171875,
		y0 = 0.3173828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-40-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3095703125,
		y0 = 0.3173828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-41-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3740234375,
		y0 = 0.3173828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-42-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.490234375,
		y0 = 0.3466796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-43-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5546875,
		y0 = 0.37451171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-44-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7216796875,
		y0 = 0.44140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-45-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8203125,
		y0 = 0.4453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-46-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.884765625,
		y0 = 0.458984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-47-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.35107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-48-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.35107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-49-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.35107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-50-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6904296875,
		y0 = 0.388671875,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-51-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2451171875,
		y0 = 0.349609375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-52-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.80419921875,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-53-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.77001953125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-54-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3095703125,
		y0 = 0.349609375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-55-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3740234375,
		y0 = 0.349609375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-56-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.490234375,
		y0 = 0.37890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-57-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5546875,
		y0 = 0.40673828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-58-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.650390625,
		y0 = 0.453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-59-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.71484375,
		y0 = 0.4736328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-60-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8017578125,
		y0 = 0.4775390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-61-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8662109375,
		y0 = 0.4912109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-62-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.439453125,
		y0 = 0.20361328125,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 12,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-63-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8017578125,
		y0 = 0.509765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-64-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9306640625,
		y0 = 0.49755859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-65-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9404296875,
		y0 = 0.0517578125,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-66-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9560546875,
		y0 = 0.40087890625,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-67-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8662109375,
		y0 = 0.5234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-68-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9306640625,
		y0 = 0.52978515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-69-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.38330078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-70-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.38330078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-71-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.38330078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-72-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2294921875,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-73-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.2939453125,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-74-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3583984375,
		y0 = 0.3818359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-75-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4228515625,
		y0 = 0.39453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-76-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4873046875,
		y0 = 0.4111328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-77-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.5517578125,
		y0 = 0.43896484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-78-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.4140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-79-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.4140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-80-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.4140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-81-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.4267578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-82-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.443359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-83-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.47119140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-84-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.47119140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-85-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.4853515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-86-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.505859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-87-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.41552734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-88-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.41552734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-89-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.41552734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-asphalt-90-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.4462890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.4462890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.4462890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.458984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.4755859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.50341796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.50341796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9404296875,
		y0 = 0.078125,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 11,
		trimmedoffsety = 12,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.517578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.5380859375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.23046875,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 11,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7890625,
		y0 = 0.4091796875,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.5419921875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.5556640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.787109375,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-15-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.56201171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-16-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.44775390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-17-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.94677734375,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-18-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.44775390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-19-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.44775390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-20-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.478515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-21-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.478515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-22-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.478515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-23-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.4912109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-24-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.5078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-25-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.53564453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-26-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.53564453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-27-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.5498046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-28-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.5703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-29-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.57421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-30-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.587890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-31-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9521484375,
		y0 = 0.43310546875,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-32-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.59423828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-33-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.47998046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-34-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.47998046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-35-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.47998046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-36-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.5107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-37-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.5107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-38-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.5107421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-39-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.5234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-40-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.5400390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-41-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.56787109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-42-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.56787109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-43-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.58203125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-44-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.6025390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-45-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.6064453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-46-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.6201171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-47-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.62646484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-48-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.51220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-49-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.619140625,
		y0 = 0.3857421875,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-50-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.51220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-51-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.9638671875,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-52-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.98095703125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-53-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.51220703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-54-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.54296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-55-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.54296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-56-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.54296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-57-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.5556640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-58-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.572265625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-59-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.60009765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-60-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.60009765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-61-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.25732421875,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 12,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-62-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.6142578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-63-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.634765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-64-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8798828125,
		y0 = 0.0869140625,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-65-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6533203125,
		y0 = 0.4091796875,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-66-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.638671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-67-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.65234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-68-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.65869140625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-69-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.54443359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-70-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.54443359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-71-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.54443359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-72-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.5751953125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-73-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.5751953125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-74-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.5751953125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-75-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.587890625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-76-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.6044921875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-77-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.63232421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-78-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.63232421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-79-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.646484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-80-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.6669921875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-81-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.6708984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-82-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.6845703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-83-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.69091796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-84-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.57666015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-85-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.57666015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-86-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.57666015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-87-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.607421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-88-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.607421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-89-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.607421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-dirt-90-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.6201171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-01-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.63671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-02-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.66455078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-03-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.66455078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-04-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4453125,
		y0 = 0.1240234375,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 11,
		trimmedoffsety = 12,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-05-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.6787109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-06-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.69921875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-07-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.2841796875,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 0,
		trimmedoffsety = 11,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-08-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6875,
		y0 = 0.4208984375,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-09-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-10-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.716796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-11-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.19140625,
		y0 = 0.80078125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-12-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.72314453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-13-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.60888671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-14-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.255859375,
		y0 = 0.80078125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 31,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-15-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.60888671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-16-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.60888671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-17-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.6396484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-18-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.6396484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-19-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.6396484375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-20-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.65234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-21-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.6689453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-22-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.69677734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-23-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.69677734375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-24-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.7109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-25-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.7314453125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-26-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.7353515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-27-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.7490234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-28-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7861328125,
		y0 = 0.44140625,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-29-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.75537109375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-30-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.64111328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-31-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.64111328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-32-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.64111328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-33-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-34-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-35-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-36-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.6845703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-37-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.701171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-38-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.72900390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-39-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.72900390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-40-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.7431640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-41-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.763671875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-42-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.767578125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-43-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.78125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-44-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.78759765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-45-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.67333984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-46-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.94921875,
		y0 = 0.46533203125,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-47-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.67333984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-48-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.3203125,
		y0 = 0.80078125,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-49-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.384765625,
		y0 = 0.8134765625,
		x1 = 0.0625,
		y1 = 0.01611328125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 33,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-50-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.67333984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-51-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.7041015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-52-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.7041015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-53-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.7041015625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-54-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.716796875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-55-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.7333984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-56-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.76123046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-57-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.76123046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-58-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.31103515625,
		x1 = 0.05078125,
		y1 = 0.02587890625,
		trimmedoffsetx = 12,
		trimmedoffsety = 0,
		trimmedwidth = 52,
		trimmedheight = 53,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-59-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.775390625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-60-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.7958984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-61-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4453125,
		y0 = 0.150390625,
		x1 = 0.0517578125,
		y1 = 0.025390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 53,
		trimmedheight = 52,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-62-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.3681640625,
		x1 = 0.0322265625,
		y1 = 0.03125,
		trimmedoffsetx = 31,
		trimmedoffsety = 0,
		trimmedwidth = 33,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-63-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.7998046875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-64-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.8134765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-65-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.81982421875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-66-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.70556640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-67-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.70556640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-68-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.70556640625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-69-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.736328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-70-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.736328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-71-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.736328125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-72-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.7490234375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-73-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.765625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-74-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.79345703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-75-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.79345703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-76-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.8076171875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-77-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.828125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-78-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.83203125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-79-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.845703125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-80-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.85205078125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-81-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.73779296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-82-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.06640625,
		y0 = 0.73779296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-83-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.130859375,
		y0 = 0.73779296875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-84-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.7685546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-85-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.259765625,
		y0 = 0.7685546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-86-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.32421875,
		y0 = 0.7685546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-87-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.388671875,
		y0 = 0.78125,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-88-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.453125,
		y0 = 0.7978515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-89-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.517578125,
		y0 = 0.82568359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["road-sand-90-back-01"] = {
		image = "miniracer-0-small",
		x0 = 0.58203125,
		y0 = 0.82568359375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["rock-01-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.693359375,
		y0 = 0.291015625,
		x1 = 0.0439453125,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 36,
		untrimmedwidth = 45,
		untrimmedheight = 36,
	},
	["rock-02-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.669921875,
		y0 = 0.14892578125,
		x1 = 0.0361328125,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 37,
		trimmedheight = 34,
		untrimmedwidth = 37,
		untrimmedheight = 34,
	},
	["rock-03-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6572265625,
		y0 = 0.22900390625,
		x1 = 0.04296875,
		y1 = 0.0166015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 44,
		trimmedheight = 34,
		untrimmedwidth = 44,
		untrimmedheight = 34,
	},
	["rock-04-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.337890625,
		x1 = 0.0498046875,
		y1 = 0.0205078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 51,
		trimmedheight = 42,
		untrimmedwidth = 51,
		untrimmedheight = 42,
	},
	["rock-05-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8798828125,
		y0 = 0.037109375,
		x1 = 0.05859375,
		y1 = 0.02392578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 49,
		untrimmedwidth = 60,
		untrimmedheight = 49,
	},
	["rock-06-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.693359375,
		y0 = 0.2490234375,
		x1 = 0.0439453125,
		y1 = 0.02001953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 41,
		untrimmedwidth = 45,
		untrimmedheight = 41,
	},
	["rock-07-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.3193359375,
		x1 = 0.0478515625,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 48,
		untrimmedwidth = 49,
		untrimmedheight = 48,
	},
	["rock-08-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.18994140625,
		x1 = 0.021484375,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 22,
		untrimmedwidth = 22,
		untrimmedheight = 22,
	},
	["rock-10-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9755859375,
		y0 = 0.224609375,
		x1 = 0.0224609375,
		y1 = 0.009765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 23,
		trimmedheight = 20,
		untrimmedwidth = 23,
		untrimmedheight = 20,
	},
	["rock-11-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9140625,
		y0 = 0.16259765625,
		x1 = 0.013671875,
		y1 = 0.0068359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 14,
		trimmedheight = 14,
		untrimmedwidth = 14,
		untrimmedheight = 14,
	},
	["rock-12-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.83203125,
		y0 = 0.1474609375,
		x1 = 0.0146484375,
		y1 = 0.00634765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 15,
		trimmedheight = 13,
		untrimmedwidth = 15,
		untrimmedheight = 13,
	},
	["rock-13-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.853515625,
		y0 = 0.1064453125,
		x1 = 0.0087890625,
		y1 = 0.00439453125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 9,
		trimmedheight = 9,
		untrimmedwidth = 9,
		untrimmedheight = 9,
	},
	["rock-14-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8203125,
		y0 = 0.14794921875,
		x1 = 0.0078125,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 8,
		trimmedheight = 8,
		untrimmedwidth = 8,
		untrimmedheight = 8,
	},
	["rock-15-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.359375,
		x1 = 0.0498046875,
		y1 = 0.0205078125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 51,
		trimmedheight = 42,
		untrimmedwidth = 51,
		untrimmedheight = 42,
	},
	["rock-16-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8798828125,
		y0 = 0.06201171875,
		x1 = 0.05859375,
		y1 = 0.02392578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 60,
		trimmedheight = 49,
		untrimmedwidth = 60,
		untrimmedheight = 49,
	},
	["rock-17-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.693359375,
		y0 = 0.27001953125,
		x1 = 0.0439453125,
		y1 = 0.02001953125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 45,
		trimmedheight = 41,
		untrimmedwidth = 45,
		untrimmedheight = 41,
	},
	["rock-18-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.1953125,
		y0 = 0.34375,
		x1 = 0.0478515625,
		y1 = 0.0234375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 49,
		trimmedheight = 48,
		untrimmedwidth = 49,
		untrimmedheight = 48,
	},
	["rock-19-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4384765625,
		y0 = 0.380859375,
		x1 = 0.021484375,
		y1 = 0.0107421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 22,
		trimmedheight = 22,
		untrimmedwidth = 22,
		untrimmedheight = 22,
	},
	["rock-20-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.974609375,
		y0 = 0.2353515625,
		x1 = 0.0224609375,
		y1 = 0.009765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 23,
		trimmedheight = 20,
		untrimmedwidth = 23,
		untrimmedheight = 20,
	},
	["rock-21-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9140625,
		y0 = 0.17041015625,
		x1 = 0.013671875,
		y1 = 0.0068359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 14,
		trimmedheight = 14,
		untrimmedwidth = 14,
		untrimmedheight = 14,
	},
	["rock-22-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9140625,
		y0 = 0.1552734375,
		x1 = 0.0146484375,
		y1 = 0.00634765625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 15,
		trimmedheight = 13,
		untrimmedwidth = 15,
		untrimmedheight = 13,
	},
	["rock-23-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8642578125,
		y0 = 0.1064453125,
		x1 = 0.0087890625,
		y1 = 0.00439453125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 9,
		trimmedheight = 9,
		untrimmedwidth = 9,
		untrimmedheight = 9,
	},
	["rock-24-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.9140625,
		y0 = 0.17822265625,
		x1 = 0.0078125,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 8,
		trimmedheight = 8,
		untrimmedwidth = 8,
		untrimmedheight = 8,
	},
	["skidmark-long-1-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.96875,
		y0 = 0.322265625,
		x1 = 0.029296875,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 30,
		trimmedheight = 96,
		untrimmedwidth = 30,
		untrimmedheight = 96,
	},
	["skidmark-long-2-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.619140625,
		y0 = 0.41796875,
		x1 = 0.029296875,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 30,
		trimmedheight = 96,
		untrimmedwidth = 30,
		untrimmedheight = 96,
	},
	["skidmark-long-3-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7099609375,
		y0 = 0.1005859375,
		x1 = 0.037109375,
		y1 = 0.046875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 38,
		trimmedheight = 96,
		untrimmedwidth = 38,
		untrimmedheight = 96,
	},
	["skidmark-short-1-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.650390625,
		y0 = 0.44140625,
		x1 = 0.029296875,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 30,
		trimmedheight = 8,
		untrimmedwidth = 30,
		untrimmedheight = 8,
	},
	["skidmark-short-2-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.650390625,
		y0 = 0.4462890625,
		x1 = 0.029296875,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 30,
		trimmedheight = 8,
		untrimmedwidth = 30,
		untrimmedheight = 8,
	},
	["skidmark-short-3-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7099609375,
		y0 = 0.1484375,
		x1 = 0.037109375,
		y1 = 0.00390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 38,
		trimmedheight = 8,
		untrimmedwidth = 38,
		untrimmedheight = 8,
	},
	["tent-blue-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.646484375,
		y0 = 0.83984375,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tent-blue-large-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4990234375,
		y0 = 0.037109375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tent-red-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7109375,
		y0 = 0.8603515625,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tent-red-large-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.6259765625,
		y0 = 0.037109375,
		x1 = 0.125,
		y1 = 0.0625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 128,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["tile-reference"] = {
		image = "miniracer-0-small",
		x0 = 0.4921875,
		y0 = 0.185546875,
		x1 = 0.0625,
		y1 = 0.03125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 64,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["tires-red-alt-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.10791015625,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["tires-red-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.12255859375,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["tires-white-alt-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8203125,
		y0 = 0.15478515625,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["tires-white-middle-01"] = {
		image = "miniracer-0-small",
		x0 = 0.8203125,
		y0 = 0.16943359375,
		x1 = 0.02734375,
		y1 = 0.013671875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 28,
		trimmedheight = 28,
		untrimmedwidth = 28,
		untrimmedheight = 28,
	},
	["tree-large-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4990234375,
		y0 = 0.1005859375,
		x1 = 0.1044921875,
		y1 = 0.0517578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 107,
		trimmedheight = 106,
		untrimmedwidth = 107,
		untrimmedheight = 106,
	},
	["tree-small-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7490234375,
		y0 = 0.14794921875,
		x1 = 0.0693359375,
		y1 = 0.03466796875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 71,
		trimmedheight = 71,
		untrimmedwidth = 71,
		untrimmedheight = 71,
	},
	["tribune-empty-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.07861328125,
		x1 = 0.21875,
		y1 = 0.0546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 224,
		trimmedheight = 112,
		untrimmedwidth = 224,
		untrimmedheight = 112,
	},
	["tribune-full-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.13427734375,
		x1 = 0.21875,
		y1 = 0.0546875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 224,
		trimmedheight = 112,
		untrimmedwidth = 224,
		untrimmedheight = 112,
	},
	["tribune-overhang-red-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.4990234375,
		y0 = 0.0009765625,
		x1 = 0.21875,
		y1 = 0.03515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 224,
		trimmedheight = 72,
		untrimmedwidth = 224,
		untrimmedheight = 72,
	},
	["tribune-overhang-striped-front-01"] = {
		image = "miniracer-0-small",
		x0 = 0.7197265625,
		y0 = 0.0009765625,
		x1 = 0.21875,
		y1 = 0.03515625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 224,
		trimmedheight = 72,
		untrimmedwidth = 224,
		untrimmedheight = 72,
	},
	["ui/font-10"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.8955078125,
		x1 = 0.0625,
		y1 = 0.017578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 36,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["ui/font-12"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.830078125,
		x1 = 0.060546875,
		y1 = 0.02392578125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 62,
		trimmedheight = 49,
		untrimmedwidth = 64,
		untrimmedheight = 64,
	},
	["ui/font-20"] = {
		image = "miniracer-0-small",
		x0 = 0.7529296875,
		y0 = 0.0771484375,
		x1 = 0.125,
		y1 = 0.0283203125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 58,
		untrimmedwidth = 128,
		untrimmedheight = 64,
	},
	["ui/font-24"] = {
		image = "miniracer-0-small",
		x0 = 0.7529296875,
		y0 = 0.037109375,
		x1 = 0.125,
		y1 = 0.0390625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 128,
		trimmedheight = 80,
		untrimmedwidth = 128,
		untrimmedheight = 128,
	},
	["ui/font-48"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.0009765625,
		x1 = 0.2490234375,
		y1 = 0.07666015625,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 255,
		trimmedheight = 157,
		untrimmedwidth = 256,
		untrimmedheight = 256,
	},
	["ui/font-8"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.8134765625,
		x1 = 0.0625,
		y1 = 0.01220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 25,
		untrimmedwidth = 64,
		untrimmedheight = 32,
	},
	["ui/icon-campaign"] = {
		image = "miniracer-0-small",
		x0 = 0.775390625,
		y0 = 0.8642578125,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/icon-google-login"] = {
		image = "miniracer-0-small",
		x0 = 0.064453125,
		y0 = 0.82666015625,
		x1 = 0.060546875,
		y1 = 0.0302734375,
		trimmedoffsetx = 5,
		trimmedoffsety = 5,
		trimmedwidth = 62,
		trimmedheight = 62,
		untrimmedwidth = 72,
		untrimmedheight = 72,
	},
	["ui/map-icon-locked"] = {
		image = "miniracer-0-small",
		x0 = 0.83984375,
		y0 = 0.8779296875,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/map-icon-unlocked-0"] = {
		image = "miniracer-0-small",
		x0 = 0.904296875,
		y0 = 0.88427734375,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/map-icon-unlocked-1"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.91552734375,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/map-icon-unlocked-2"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.91552734375,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/map-icon-unlocked-3"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.91552734375,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/map-icon-unlocked"] = {
		image = "miniracer-0-small",
		x0 = 0.001953125,
		y0 = 0.85791015625,
		x1 = 0.0625,
		y1 = 0.0302734375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 64,
		trimmedheight = 62,
		untrimmedwidth = 64,
		untrimmedheight = 62,
	},
	["ui/mouse"] = {
		image = "miniracer-0-small",
		x0 = 0.22265625,
		y0 = 0.13720703125,
		x1 = 0.0263671875,
		y1 = 0.01318359375,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 27,
		trimmedheight = 27,
		untrimmedwidth = 27,
		untrimmedheight = 27,
	},
	["ui/star-bronze"] = {
		image = "miniracer-0-small",
		x0 = 0.83203125,
		y0 = 0.12255859375,
		x1 = 0.015625,
		y1 = 0.00732421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 16,
		trimmedheight = 15,
		untrimmedwidth = 16,
		untrimmedheight = 15,
	},
	["ui/star-gold"] = {
		image = "miniracer-0-small",
		x0 = 0.83203125,
		y0 = 0.130859375,
		x1 = 0.015625,
		y1 = 0.00732421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 16,
		trimmedheight = 15,
		untrimmedwidth = 16,
		untrimmedheight = 15,
	},
	["ui/star-silver"] = {
		image = "miniracer-0-small",
		x0 = 0.83203125,
		y0 = 0.13916015625,
		x1 = 0.015625,
		y1 = 0.00732421875,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 16,
		trimmedheight = 15,
		untrimmedwidth = 16,
		untrimmedheight = 15,
	},
	["ui/ui-scene-cave-ice"] = {
		image = "miniracer-0-small",
		x0 = 0.2529296875,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.1220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui/ui-scene-caveart-ice"] = {
		image = "miniracer-0-small",
		x0 = 0.2529296875,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.1220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui/ui-scene-player"] = {
		image = "miniracer-0-small",
		x0 = 0.2529296875,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.1220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui/ui-scene-tile1-ice"] = {
		image = "miniracer-0-small",
		x0 = 0.2529296875,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.1220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
	["ui/ui-scene-tile2-ice"] = {
		image = "miniracer-0-small",
		x0 = 0.2529296875,
		y0 = 0.0009765625,
		x1 = 0.244140625,
		y1 = 0.1220703125,
		trimmedoffsetx = 0,
		trimmedoffsety = 0,
		trimmedwidth = 250,
		trimmedheight = 250,
		untrimmedwidth = 250,
		untrimmedheight = 250,
	},
}
